Coverage for /home/tribaal/workspace/django-shop/shop/models/cartmodel: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/models/cartmodel : 100.00%

## 7 statements 7 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 | # -*- coding: utf-8 -*- """ This overrides the various models with classes loaded from the corresponding setting if it exists. """ from django.conf import settings from shop.util.loader import load_class #============================================================================== # Extensibility #============================================================================== # Cart model CART_MODEL = getattr(settings, 'SHOP_CART_MODEL', 'shop.models.defaults.cart.Cart') Cart = load_class(CART_MODEL, 'SHOP_CART_MODEL') # Cart item model CARTITEM_MODEL = getattr(settings, 'SHOP_CARTITEM_MODEL', 'shop.models.defaults.cartitem.CartItem') CartItem = load_class(CARTITEM_MODEL, 'SHOP_CARTITEM_MODEL')